@@ -58,6 +58,11 @@ class peek(HexViewer):
             stdout=stdout,
         )
 
+    @HexViewer.Requires('colorama')
+    def _colorama():
+        import colorama
+        return colorama
+
     def process(self, data):
         lines = self._peeklines(data)
         if self.args.stdout:
@@ -65,9 +70,13 @@ class peek(HexViewer):
                 yield line.encode(self.codec)
             return
         if not self.args.gray:
-            from colorama import Back as BG, Fore as FG, Style as S
+            cr = self._colorama
+            BG = cr.Back
+            FG = cr.Fore
+            ST = cr.Style
+            cr.init()
             _erase = ' ' * get_terminal_size()
-            _reset = F'\r{BG.BLACK}{FG.WHITE}{S.RESET_ALL}{_erase}\r'
+            _reset = F'\r{BG.BLACK}{FG.WHITE}{ST.RESET_ALL}{_erase}\r'
         else:
             _reset = ''
         try:
@@ -208,15 +217,16 @@ class peek(HexViewer):
         if self.args.brief:
             final = False
         elif not self.args.bare:
-            peek = repr(meta.size).strip()
+            peek = repr(meta.size)
+            magic = meta.magic
             if len(data) <= 5_000_000:
                 peek = F'{peek}; {meta.entropy!r} entropy'
-            peek = F'{peek}; {meta.magic!s}'
             if not self.args.meta:
                 if meta:
-                    variables = ',\x20'.join(meta)
-                    peek = F'{peek}\n\x20\x20(meta: {variables})'
+                    variables = ','.join(meta)
+                    peek = F'{peek}; variables: {variables}'
                 meta = {}
+            peek = F'{peek}; {magic!s}'
             if self.args.meta > 1:
                 meta['size']
                 meta['entropy']
